@@ -31,13 +31,10 @@ from sugar import util
 from sugar.bundle.bundle import Bundle, \
     MalformedBundleException, NotInstalledException
 
-from sugar.bundle.bundleversion import NormalizedVersion
-from sugar.bundle.bundleversion import InvalidVersionError
-
 
 class ActivityBundle(Bundle):
     """A Sugar activity bundle
-    
+
     See http://wiki.laptop.org/go/Activity_bundles for details
     """
 
@@ -52,13 +49,15 @@ class ActivityBundle(Bundle):
         Bundle.__init__(self, path)
         self.activity_class = None
         self.bundle_exec = None
-        
+
         self._name = None
+        self._local_name = None
         self._icon = None
         self._bundle_id = None
         self._mime_types = None
         self._show_launcher = True
-        self._activity_version = '0'
+        self._tags = None
+        self._activity_version = 0
         self._installation_time = os.stat(path).st_mtime
         self._manifest = None
 
@@ -71,6 +70,9 @@ class ActivityBundle(Bundle):
         if linfo_file:
             self._parse_linfo(linfo_file)
 
+        if self._local_name == None:
+           self._local_name = self._name
+
     def _get_manifest(self):
         if self._manifest is None:
             self._manifest = self._read_manifest()
@@ -86,16 +88,16 @@ class ActivityBundle(Bundle):
         if not f:
             logging.warning("Activity directory lacks a MANIFEST file.")
             return []
-        
-        ret = [line.strip() for line in f.readlines()] 
+
+        ret = [line.strip() for line in f.readlines()]
         f.close()
         return ret
-        
+
     def _read_manifest(self):
-        """return a list with the lines in MANIFEST, with invalid lines replaced
-        by empty lines.
-        
-        Since absolute order carries information on file history, it should 
+        """return a list with the lines in MANIFEST, with invalid lines
+        replaced by empty lines.
+
+        Since absolute order carries information on file history, it should
         be preserved. For instance, when renaming a file, you should leave
         the new name on the same line as the old one.
         """
@@ -113,24 +115,24 @@ class ActivityBundle(Bundle):
             # Remove duplicates
             if line in lines[0:num]:
                 lines[num] = ""
-                logging.warning("Bundle %s: duplicate entry in MANIFEST: %s"
-                                % (self._name,line))
+                logging.warning('Bundle %s: duplicate entry in MANIFEST: %s',
+                    self._name, line)
                 continue
-            
+
             # Remove MANIFEST
             if line == "MANIFEST":
                 lines[num] = ""
-                logging.warning("Bundle %s: MANIFEST includes itself: %s"
-                                % (self._name,line))
-                
+                logging.warning('Bundle %s: MANIFEST includes itself: %s',
+                    self._name, line)
+
             # Remove invalid files
             if not self.is_file(line):
                 lines[num] = ""
-                logging.warning("Bundle %s: invalid entry in MANIFEST: %s"
-                                % (self._name,line))
+                logging.warning('Bundle %s: invalid entry in MANIFEST: %s',
+                    self._name, line)
 
         return lines
-    
+
     def get_files(self, manifest = None):
         files = [line for line in (manifest or self.manifest) if line]
 
@@ -138,7 +140,7 @@ class ActivityBundle(Bundle):
             files.append('MANIFEST')
 
         return files
-      
+
     def _parse_info(self, info_file):
         cp = ConfigParser()
         cp.readfp(info_file)
@@ -173,24 +175,27 @@ class ActivityBundle(Bundle):
 
         if cp.has_option(section, 'mime_types'):
             mime_list = cp.get(section, 'mime_types').strip(';')
-            self._mime_types = [ mime.strip() for mime in mime_list.split(';') ]
+            self._mime_types = [mime.strip() for mime in mime_list.split(';')]
 
         if cp.has_option(section, 'show_launcher'):
             if cp.get(section, 'show_launcher') == 'no':
                 self._show_launcher = False
 
+        if cp.has_option(section, 'tags'):
+            tag_list = cp.get(section, 'tags').strip(';')
+            self._tags = [tag.strip() for tag in tag_list.split(';')]
+
         if cp.has_option(section, 'icon'):
             self._icon = cp.get(section, 'icon')
 
         if cp.has_option(section, 'activity_version'):
             version = cp.get(section, 'activity_version')
             try:
-                NormalizedVersion(version)
-            except InvalidVersionError:
+                self._activity_version = int(version)
+            except ValueError:
                 raise MalformedBundleException(
-                    'Activity bundle %s has invalid version number %s' % \
+                    'Activity bundle %s has invalid version number %s' %
                     (self._path, version))
-            self._activity_version = version
 
     def _get_linfo_file(self):
         lang = locale.getdefaultlocale()[0]
@@ -216,7 +221,11 @@ class ActivityBundle(Bundle):
         section = 'Activity'
 
         if cp.has_option(section, 'name'):
-            self._name = cp.get(section, 'name')
+            self._local_name = cp.get(section, 'name')
+
+        if cp.has_option(section, 'tags'):
+            tag_list = cp.get(section, 'tags').strip(';')
+            self._tags = [tag.strip() for tag in tag_list.split(';')]
 
     def get_locale_path(self):
         """Get the locale path inside the (installed) activity bundle."""
@@ -235,7 +244,11 @@ class ActivityBundle(Bundle):
         return self._path
 
     def get_name(self):
-        """Get the activity user visible name."""
+        """Get the activity user-visible name."""
+        return self._local_name
+
+    def get_bundle_name(self):
+        """Get the activity bundle name."""
         return self._name
 
     def get_installation_time(self):
@@ -247,16 +260,17 @@ class ActivityBundle(Bundle):
         """Get the activity bundle id"""
         return self._bundle_id
 
-    # FIXME: this should return the icon data, not a filename, so that
-    # we don't need to create a temp file in the zip case
     def get_icon(self):
         """Get the activity icon name"""
+        # FIXME: this should return the icon data, not a filename, so that
+        # we don't need to create a temp file in the zip case
         icon_path = os.path.join('activity', self._icon + '.svg')
         if self._zip_file is None:
             return os.path.join(self._path, icon_path)
         else:
             icon_data = self.get_file(icon_path).read()
-            temp_file, temp_file_path = tempfile.mkstemp(prefix=self._icon, suffix='.svg')
+            temp_file, temp_file_path = tempfile.mkstemp(prefix=self._icon,
+                                                         suffix='.svg')
             os.write(temp_file, icon_data)
             os.close(temp_file)
             return util.TempFilePath(temp_file_path)
@@ -278,6 +292,10 @@ class ActivityBundle(Bundle):
         """Get the MIME types supported by the activity"""
         return self._mime_types
 
+    def get_tags(self):
+        """Get the tags that describe the activity"""
+        return self._tags
+
     def get_show_launcher(self):
         """Get whether there should be a visible launcher for the activity"""
         return self._show_launcher
@@ -289,29 +307,29 @@ class ActivityBundle(Bundle):
         self._unzip(install_dir)
 
         install_path = os.path.join(install_dir, self._zip_root_dir)
-        
+
         # List installed files
         manifestfiles = self.get_files(self._raw_manifest())
-        paths  = []
+        paths = []
         for root, dirs_, files in os.walk(install_path):
             rel_path = root[len(install_path) + 1:]
             for f in files:
                 paths.append(os.path.join(rel_path, f))
-                
+
         # Check the list against the MANIFEST
         for path in paths:
             if path in manifestfiles:
                 manifestfiles.remove(path)
             elif path != "MANIFEST":
-                logging.warning("Bundle %s: %s not in MANIFEST"%
-                                (self._name,path))
+                logging.warning('Bundle %s: %s not in MANIFEST', self._name,
+                    path)
                 if strict_manifest:
                     os.remove(os.path.join(install_path, path))
-                    
+
         # Is anything in MANIFEST left over after accounting for all files?
         if manifestfiles:
             err = ("Bundle %s: files in MANIFEST not included: %s"%
-                   (self._name,str(manifestfiles)))
+                   (self._name, str(manifestfiles)))
             if strict_manifest:
                 raise MalformedBundleException(err)
             else:
@@ -342,7 +360,7 @@ class ActivityBundle(Bundle):
         mime_types = self.get_mime_types()
         if mime_types is not None:
             installed_icons_dir = os.path.join(xdg_data_home,
-                                               'icons/sugar/scalable/mimetypes')
+                'icons/sugar/scalable/mimetypes')
             if not os.path.isdir(installed_icons_dir):
                 os.makedirs(installed_icons_dir)
 
@@ -352,11 +370,11 @@ class ActivityBundle(Bundle):
                 svg_file = mime_icon_base + '.svg'
                 info_file = mime_icon_base + '.icon'
                 self._symlink(svg_file,
-                              os.path.join(installed_icons_dir,
-                                           os.path.basename(svg_file)))
+                        os.path.join(installed_icons_dir,
+                            os.path.basename(svg_file)))
                 self._symlink(info_file,
-                              os.path.join(installed_icons_dir,
-                                           os.path.basename(info_file)))
+                        os.path.join(installed_icons_dir,
+                            os.path.basename(info_file)))
 
     def _symlink(self, src, dst):
         if not os.path.isfile(src):
@@ -391,7 +409,7 @@ class ActivityBundle(Bundle):
         mime_types = self.get_mime_types()
         if mime_types is not None:
             installed_icons_dir = os.path.join(xdg_data_home,
-                                               'icons/sugar/scalable/mimetypes')
+                'icons/sugar/scalable/mimetypes')
             if os.path.isdir(installed_icons_dir):
                 for f in os.listdir(installed_icons_dir):
                     path = os.path.join(installed_icons_dir, f)
@@ -400,3 +418,6 @@ class ActivityBundle(Bundle):
                         os.remove(path)
 
         self._uninstall(install_path)
+
+    def is_user_activity(self):
+        return self.get_path().startswith(env.get_user_activities_path())
