@@ -29,8 +29,6 @@ from sugar import env
 from sugar.bundle.bundle import Bundle, NotInstalledException, \
     MalformedBundleException
 
-from sugar.bundle.bundleversion import NormalizedVersion
-from sugar.bundle.bundleversion import InvalidVersionError
 
 class ContentBundle(Bundle):
     """A Sugar content bundle
@@ -54,7 +52,7 @@ class ContentBundle(Bundle):
         self._subcategory = None
         self._category_class = None
         self._category_icon = None
-        self._library_version = '0'
+        self._library_version = None
         self._bundle_class = None
         self._activity_start = None
         self._global_name = None
@@ -76,18 +74,6 @@ class ContentBundle(Bundle):
 
         section = 'Library'
 
-        if cp.has_option(section, 'host_version'):
-            version = cp.get(section, 'host_version')
-            try:
-                if int(version) != 1:
-                    raise MalformedBundleException(
-                        'Content bundle %s has unknown host_version number %s' %
-                        (self._path, version))
-            except ValueError:
-                raise MalformedBundleException(
-                    'Content bundle %s has invalid host_version number %s' %
-                    (self._path, version))
-
         if cp.has_option(section, 'name'):
             self._name = cp.get(section, 'name')
         else:
@@ -97,12 +83,11 @@ class ContentBundle(Bundle):
         if cp.has_option(section, 'library_version'):
             version = cp.get(section, 'library_version')
             try:
-                NormalizedVersion(version)
-            except InvalidVersionError:
+                self._library_version = int(version)
+            except ValueError:
                 raise MalformedBundleException(
                     'Content bundle %s has invalid version number %s' %
                     (self._path, version))
-            self._library_version = version
 
         if cp.has_option(section, 'l10n'):
             l10n = cp.get(section, 'l10n')
@@ -213,17 +198,17 @@ class ContentBundle(Bundle):
     def get_start_uri(self):
         return "file://" + urllib.pathname2url(self.get_start_path())
 
-    # TODO treat ContentBundle in special way
-    # needs rethinking while fixing ContentBundle support
     def get_bundle_id(self):
+        # TODO treat ContentBundle in special way
+        # needs rethinking while fixing ContentBundle support
         if self._bundle_class is not None:
             return self._bundle_class
         else:
             return self._global_name
 
-    # TODO treat ContentBundle in special way
-    # needs rethinking while fixing ContentBundle support
     def get_activity_version(self):
+        # TODO treat ContentBundle in special way
+        # needs rethinking while fixing ContentBundle support
         return self._library_version
 
     def is_installed(self):
