@@ -33,9 +33,12 @@ import cairo
 from sugar.graphics.xocolor import XoColor
 from sugar.util import LRU
 
+
 _BADGE_SIZE = 0.45
 
+
 class _SVGLoader(object):
+
     def __init__(self):
         self._cache = LRU(50)
 
@@ -61,20 +64,26 @@ class _SVGLoader(object):
         import rsvg # XXX this is very slow!  why?
         return rsvg.Handle(data=icon)
 
+
 class _IconInfo(object):
+
     def __init__(self):
         self.file_name = None
         self.attach_x = 0
         self.attach_y = 0
 
+
 class _BadgeInfo(object):
+
     def __init__(self):
         self.attach_x = 0
         self.attach_y = 0
         self.size = 0
         self.icon_padding = 0
 
+
 class _IconBuffer(object):
+
     _surface_cache = LRU(50)
     _loader = _SVGLoader()
 
@@ -143,8 +152,8 @@ class _IconBuffer(object):
 
                 del info
             else:
-                logging.warning('No icon with the name %s '
-                                'was found in the theme.' % self.icon_name)
+                logging.warning('No icon with the name %s was found in the '
+                    'theme.', self.icon_name)
 
         return icon_info
 
@@ -219,7 +228,7 @@ class _IconBuffer(object):
             self.stroke_color = None
             self.fill_color = None
 
-    def _get_insensitive_pixbuf (self, pixbuf, widget):
+    def _get_insensitive_pixbuf(self, pixbuf, widget):
         if not (widget and widget.style):
             return pixbuf
 
@@ -309,11 +318,16 @@ class _IconBuffer(object):
 
     xo_color = property(_get_xo_color, _set_xo_color)
 
+
 class Icon(gtk.Image):
+
     __gtype_name__ = 'SugarIcon'
 
     def __init__(self, **kwargs):
         self._buffer = _IconBuffer()
+        # HACK: need to keep a reference to the path so it doesn't get garbage
+        # collected while it's still used if it's a sugar.util.TempFilePath.
+        # See #1175
         self._file = None
 
         gobject.GObject.__init__(self, **kwargs)
@@ -325,8 +339,6 @@ class Icon(gtk.Image):
         self._file = file_name
         self._buffer.file_name = file_name
 
-    # XXX we need to override file property to support auto_ptr objects
-    # that used to represent temporaly unzipped icons from bundles, see #1175
     file = gobject.property(type=object, setter=set_file, getter=get_file)
 
     def _sync_image_properties(self):
@@ -336,10 +348,10 @@ class Icon(gtk.Image):
         if self._buffer.file_name != self.props.file:
             self._buffer.file_name = self.props.file
 
-        if self.props.pixel_size == -1:    
+        if self.props.pixel_size == -1:
             width, height = gtk.icon_size_lookup(self.props.icon_size)
         else:
-            width = height = self.props.pixel_size 
+            width = height = self.props.pixel_size
         if self._buffer.width != width or self._buffer.height != height:
             self._buffer.width = width
             self._buffer.height = height
@@ -509,7 +521,9 @@ class Icon(gtk.Image):
     badge_name = gobject.property(
         type=str, getter=get_badge_name, setter=set_badge_name)
 
+
 class CanvasIcon(hippo.CanvasBox, hippo.CanvasItem):
+
     __gtype_name__ = 'CanvasIcon'
 
     def __init__(self, **kwargs):
@@ -916,7 +930,7 @@ class CanvasIcon(hippo.CanvasBox, hippo.CanvasItem):
 
     def get_palette_invoker(self):
         return self._palette_invoker
-    
+
     def set_palette_invoker(self, palette_invoker):
         self._palette_invoker.detach()
         self._palette_invoker = palette_invoker
@@ -928,8 +942,189 @@ class CanvasIcon(hippo.CanvasBox, hippo.CanvasItem):
         from sugar.graphics.palette import Palette
 
         self.set_palette(Palette(text))
-    
-    palette = property(get_palette, set_palette)
+
+
+class CellRendererIcon(gtk.GenericCellRenderer):
+
+    __gtype_name__ = 'SugarCellRendererIcon'
+
+    __gsignals__ = {
+        'clicked': (gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, [object]),
+    }
+
+    def __init__(self, tree_view):
+        from sugar.graphics.palette import CellRendererInvoker
+
+        self._buffer = _IconBuffer()
+        self._buffer.cache = True
+        self._xo_color = None
+        self._fill_color = None
+        self._stroke_color = None
+        self._prelit_fill_color = None
+        self._prelit_stroke_color = None
+        self._palette_invoker = CellRendererInvoker()
+
+        gobject.GObject.__init__(self)
+
+        self._palette_invoker.attach_cell_renderer(tree_view, self)
+
+        self.connect('destroy', self.__destroy_cb)
+
+    def __destroy_cb(self, icon):
+        self._palette_invoker.detach()
+
+    def create_palette(self):
+        return None
+
+    def get_palette_invoker(self):
+        return self._palette_invoker
+
+    palette_invoker = gobject.property(type=object, getter=get_palette_invoker)
+
+    def set_file_name(self, value):
+        if self._buffer.file_name != value:
+            self._buffer.file_name = value
+
+    file_name = gobject.property(type=str, setter=set_file_name)
+
+    def set_icon_name(self, value):
+        if self._buffer.icon_name != value:
+            self._buffer.icon_name = value
+
+    icon_name = gobject.property(type=str, setter=set_icon_name)
+
+    def get_xo_color(self):
+        return self._xo_color
+
+    def set_xo_color(self, value):
+        self._xo_color = value
+
+    xo_color = gobject.property(type=object,
+            getter=get_xo_color, setter=set_xo_color)
+
+    def set_fill_color(self, value):
+        if self._fill_color != value:
+            self._fill_color = value
+
+    fill_color = gobject.property(type=object, setter=set_fill_color)
+
+    def set_stroke_color(self, value):
+        if self._stroke_color != value:
+            self._stroke_color = value
+
+    stroke_color = gobject.property(type=object, setter=set_stroke_color)
+
+    def set_prelit_fill_color(self, value):
+        if self._prelit_fill_color != value:
+            self._prelit_fill_color = value
+
+    prelit_fill_color = gobject.property(type=object,
+                                         setter=set_prelit_fill_color)
+
+    def set_prelit_stroke_color(self, value):
+        if self._prelit_stroke_color != value:
+            self._prelit_stroke_color = value
+
+    prelit_stroke_color = gobject.property(type=object,
+                                           setter=set_prelit_stroke_color)
+
+    def set_background_color(self, value):
+        if self._buffer.background_color != value:
+            self._buffer.background_color = value
+
+    background_color = gobject.property(type=object,
+                                        setter=set_background_color)
+
+    def set_size(self, value):
+        if self._buffer.width != value:
+            self._buffer.width = value
+            self._buffer.height = value
+
+    size = gobject.property(type=object, setter=set_size)
+
+    def on_get_size(self, widget, cell_area):
+        width = self._buffer.width + self.props.xpad * 2
+        height = self._buffer.height + self.props.ypad * 2
+        xoffset = 0
+        yoffset = 0
+
+        if width > 0 and height > 0 and cell_area is not None:
+
+            if widget.get_direction() == gtk.TEXT_DIR_RTL:
+                xoffset = 1.0 - self.props.xalign
+            else:
+                xoffset = self.props.xalign
+
+            xoffset = max(xoffset * (cell_area.width - width), 0)
+            yoffset = max(self.props.yalign * (cell_area.height - height), 0)
+
+        return xoffset, yoffset, width, height
+
+    def on_activate(self, event, widget, path, background_area, cell_area,
+                    flags):
+        pass
+
+    def on_start_editing(self, event, widget, path, background_area, cell_area,
+                         flags):
+        pass
+
+    def _is_prelit(self, tree_view):
+        x, y = tree_view.get_pointer()
+        x, y = tree_view.convert_widget_to_bin_window_coords(x, y)
+        pos = tree_view.get_path_at_pos(x, y)
+        if pos is None:
+            return False
+
+        path_, column, x, y = pos
+
+        for cell_renderer in column.get_cell_renderers():
+            if cell_renderer == self:
+                cell_x, cell_width = column.cell_get_position(cell_renderer)
+                if x > cell_x and x < (cell_x + cell_width):
+                    return True
+                return False
+
+        return False
+
+    def on_render(self, window, widget, background_area, cell_area,
+            expose_area, flags):
+        if self._xo_color is not None:
+            stroke_color = self._xo_color.get_stroke_color()
+            fill_color = self._xo_color.get_fill_color()
+            prelit_fill_color = None
+            prelit_stroke_color = None
+        else:
+            stroke_color = self._stroke_color
+            fill_color = self._fill_color
+            prelit_fill_color = self._prelit_fill_color
+            prelit_stroke_color = self._prelit_stroke_color
+
+        has_prelit_colors = None not in [prelit_fill_color,
+                                         prelit_stroke_color]
+
+        if flags & gtk.CELL_RENDERER_PRELIT and has_prelit_colors and \
+                self._is_prelit(widget):
+
+            self._buffer.fill_color = prelit_fill_color
+            self._buffer.stroke_color = prelit_stroke_color
+        else:
+            self._buffer.fill_color = fill_color
+            self._buffer.stroke_color = stroke_color
+
+        surface = self._buffer.get_surface()
+        if surface is None:
+            return
+
+        xoffset, yoffset, width_, height_ = self.on_get_size(widget, cell_area)
+
+        x = cell_area.x + xoffset
+        y = cell_area.y + yoffset
+
+        cr = window.cairo_create()
+        cr.set_source_surface(surface, math.floor(x), math.floor(y))
+        cr.rectangle(expose_area)
+        cr.paint()
+
 
 def get_icon_state(base_name, perc, step=5):
     strength = round(perc / step) * step
@@ -942,6 +1137,7 @@ def get_icon_state(base_name, perc, step=5):
 
         strength = strength + step
 
+
 def get_icon_file_name(icon_name):
     icon_theme = gtk.icon_theme_get_default()
     info = icon_theme.lookup_icon(icon_name, gtk.ICON_SIZE_LARGE_TOOLBAR, 0)
@@ -951,3 +1147,30 @@ def get_icon_file_name(icon_name):
     del info
     return filename
 
+
+def get_surface(**kwargs):
+    """Get cached cairo surface.
+
+        Keyword arguments:
+        icon_name        -- name of icon to load, default None
+        file_name        -- path to image file, default None
+        fill_color       -- for svg images, change default fill color
+                            default None
+        stroke_color     -- for svg images, change default stroke color
+                            default None
+        background_color -- draw background or surface will be transparent
+                            default None
+        badge_name       -- name of icon which will be drawn on top of
+                            original image, default None
+        width            -- change image width, default None
+        height           -- change image height, default None
+        cache            -- if image is svg, keep svg file content for later
+        scale            -- scale image, default 1.0
+
+        Return: cairo surface or None if image was not found
+
+        """
+    icon = _IconBuffer()
+    for key, value in kwargs.items():
+        icon.__setattr__(key, value)
+    return icon.get_surface()
