@@ -16,7 +16,7 @@
 # Boston, MA 02111-1307, USA.
 
 """
-UNSTABLE. Used only internally by Activity and jarabe. 
+UNSTABLE. Used only internally by Activity and jarabe.
 """
 
 import gtk
@@ -31,12 +31,11 @@ def _property_get_trapped(window, prop, prop_type):
     error = gtk.gdk.error_trap_pop()
     if error:
         logging.debug('Received X Error (%i) while getting '
-                      'a property on a window', error)
+                      'a property on a window' % error)
 
     return prop_info
 
 def _property_change_trapped(window, prop, prop_type, format, mode, data):
-    # pylint: disable=W0622
     gtk.gdk.error_trap_push()
 
     window.property_change(prop, prop_type, format, mode, data)
@@ -44,10 +43,11 @@ def _property_change_trapped(window, prop, prop_type, format, mode, data):
     error = gtk.gdk.error_trap_pop()
     if error:
         logging.debug('Received X Error (%i) while setting '
-                      'a property on a window', error)
+                      'a property on a window' % error)
         raise RuntimeError('Received X Error (%i) while setting '
                            'a property on a window' % error)
     
+
 def get_activity_id(wnck_window):
     window = gtk.gdk.window_foreign_new(wnck_window.get_xid())
     prop_info = _property_get_trapped(window, '_SUGAR_ACTIVITY_ID', 'STRING')
@@ -56,6 +56,7 @@ def get_activity_id(wnck_window):
     else:
         return prop_info[2]
 
+
 def get_bundle_id(wnck_window):
     window = gtk.gdk.window_foreign_new(wnck_window.get_xid())
     prop_info = _property_get_trapped(window, '_SUGAR_BUNDLE_ID', 'STRING')
@@ -64,10 +65,21 @@ def get_bundle_id(wnck_window):
     else:
         return prop_info[2]
 
+
+def get_sugar_window_type(wnck_window):
+    window = gtk.gdk.window_foreign_new(wnck_window.get_xid())
+    prop_info = _property_get_trapped(window, '_SUGAR_WINDOW_TYPE', 'STRING')
+    if prop_info is None:
+        return None
+    else:
+        return prop_info[2]
+
+
 def set_activity_id(window, activity_id):
     _property_change_trapped(window, '_SUGAR_ACTIVITY_ID', 'STRING', 8,
                              gtk.gdk.PROP_MODE_REPLACE, activity_id)
 
+
 def set_bundle_id(window, bundle_id):
     _property_change_trapped(window, '_SUGAR_BUNDLE_ID', 'STRING', 8,
                              gtk.gdk.PROP_MODE_REPLACE, bundle_id)
